pub type FastSet4<V> = HashSet<V, BuildHasherDefault<FxHasher32>>;Expand description
A fast set that is not resistant to collision attacks. Works on 4 bytes at a time.
Aliased Type
pub struct FastSet4<V> { /* private fields */ }pub type FastSet4<V> = HashSet<V, BuildHasherDefault<FxHasher32>>;A fast set that is not resistant to collision attacks. Works on 4 bytes at a time.
pub struct FastSet4<V> { /* private fields */ }